==> zio-aws-sagemaker_2.12-5.17.295.11-sources.jar: zio/aws/sagemaker/model/CreateEndpointConfigRequest.scala <==
package zio.aws.sagemaker.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.sagemaker.model.primitives.{KmsKeyId, EndpointConfigName}
import scala.jdk.CollectionConverters._
final case class CreateEndpointConfigRequest(
    endpointConfigName: EndpointConfigName,
    productionVariants: Iterable[zio.aws.sagemaker.model.ProductionVariant],
    dataCaptureConfig: Optional[zio.aws.sagemaker.model.DataCaptureConfig] =
      Optional.Absent,
    tags: Optional[Iterable[zio.aws.sagemaker.model.Tag]] = Optional.Absent,
    kmsKeyId: Optional[KmsKeyId] = Optional.Absent,
    asyncInferenceConfig: Optional[
      zio.aws.sagemaker.model.AsyncInferenceConfig
    ] = Optional.Absent,
    explainerConfig: Optional[zio.aws.sagemaker.model.ExplainerConfig] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.CreateEndpointConfigRequest = {
    import CreateEndpointConfigRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.CreateEndpointConfigRequest
      .builder()
      .endpointConfigName(
        EndpointConfigName.unwrap(endpointConfigName): java.lang.String
      )
      .productionVariants(productionVariants.map { item =>
        item.buildAwsValue()
      }.asJavaCollection)
      .optionallyWith(dataCaptureConfig.map(value => value.buildAwsValue()))(
        _.dataCaptureConfig
      )
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .optionallyWith(
        kmsKeyId.map(value => KmsKeyId.unwrap(value): java.lang.String)
      )(_.kmsKeyId)
      .optionallyWith(asyncInferenceConfig.map(value => value.buildAwsValue()))(
        _.asyncInferenceConfig
      )
      .optionallyWith(explainerConfig.map(value => value.buildAwsValue()))(
        _.explainerConfig
      )
      .build()
  }
  def asReadOnly: zio.aws.sagemaker.model.CreateEndpointConfigRequest.ReadOnly =
    zio.aws.sagemaker.model.CreateEndpointConfigRequest.wrap(buildAwsValue())
}
object CreateEndpointConfigRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.CreateEndpointConfigRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.CreateEndpointConfigRequest =
      zio.aws.sagemaker.model.CreateEndpointConfigRequest(
        endpointConfigName,
        productionVariants.map { item =>
          item.asEditable
        },
        dataCaptureConfig.map(value => value.asEditable),
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        kmsKeyId.map(value => value),
        asyncInferenceConfig.map(value => value.asEditable),
        explainerConfig.map(value => value.asEditable)
      )
    def endpointConfigName: EndpointConfigName
    def productionVariants
        : List[zio.aws.sagemaker.model.ProductionVariant.ReadOnly]
    def dataCaptureConfig
        : Optional[zio.aws.sagemaker.model.DataCaptureConfig.ReadOnly]
    def tags: Optional[List[zio.aws.sagemaker.model.Tag.ReadOnly]]
    def kmsKeyId: Optional[KmsKeyId]
    def asyncInferenceConfig
        : Optional[zio.aws.sagemaker.model.AsyncInferenceConfig.ReadOnly]
    def explainerConfig
        : Optional[zio.aws.sagemaker.model.ExplainerConfig.ReadOnly]
    def getEndpointConfigName: ZIO[Any, Nothing, EndpointConfigName] =
      ZIO.succeed(endpointConfigName)
    def getProductionVariants: ZIO[Any, Nothing, List[
      zio.aws.sagemaker.model.ProductionVariant.ReadOnly
    ]] = ZIO.succeed(productionVariants)
    def getDataCaptureConfig: ZIO[
      Any,
      AwsError,
      zio.aws.sagemaker.model.DataCaptureConfig.ReadOnly
    ] = AwsError.unwrapOptionField("dataCaptureConfig", dataCaptureConfig)
    def getTags
        : ZIO[Any, AwsError, List[zio.aws.sagemaker.model.Tag.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
    def getKmsKeyId: ZIO[Any, AwsError, KmsKeyId] =
      AwsError.unwrapOptionField("kmsKeyId", kmsKeyId)
    def getAsyncInferenceConfig: ZIO[
      Any,
      AwsError,
      zio.aws.sagemaker.model.AsyncInferenceConfig.ReadOnly
    ] = AwsError.unwrapOptionField("asyncInferenceConfig", asyncInferenceConfig)
    def getExplainerConfig
        : ZIO[Any, AwsError, zio.aws.sagemaker.model.ExplainerConfig.ReadOnly] =
      AwsError.unwrapOptionField("explainerConfig", explainerConfig)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.CreateEndpointConfigRequest
  ) extends zio.aws.sagemaker.model.CreateEndpointConfigRequest.ReadOnly {
    override val endpointConfigName: EndpointConfigName =
      zio.aws.sagemaker.model.primitives
        .EndpointConfigName(impl.endpointConfigName())
    override val productionVariants
        : List[zio.aws.sagemaker.model.ProductionVariant.ReadOnly] = impl
      .productionVariants()
      .asScala
      .map { item =>
        zio.aws.sagemaker.model.ProductionVariant.wrap(item)
      }
      .toList
    override val dataCaptureConfig
        : Optional[zio.aws.sagemaker.model.DataCaptureConfig.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.dataCaptureConfig())
        .map(value => zio.aws.sagemaker.model.DataCaptureConfig.wrap(value))
    override val tags: Optional[List[zio.aws.sagemaker.model.Tag.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.tags())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.sagemaker.model.Tag.wrap(item)
          }.toList
        )
    override val kmsKeyId: Optional[KmsKeyId] = zio.aws.core.internal
      .optionalFromNullable(impl.kmsKeyId())
      .map(value => zio.aws.sagemaker.model.primitives.KmsKeyId(value))
    override val asyncInferenceConfig
        : Optional[zio.aws.sagemaker.model.AsyncInferenceConfig.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.asyncInferenceConfig())
        .map(value => zio.aws.sagemaker.model.AsyncInferenceConfig.wrap(value))
    override val explainerConfig
        : Optional[zio.aws.sagemaker.model.ExplainerConfig.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.explainerConfig())
        .map(value => zio.aws.sagemaker.model.ExplainerConfig.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.CreateEndpointConfigRequest
  ): zio.aws.sagemaker.model.CreateEndpointConfigRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-sagemaker_2.12-5.19.12.1-sources.jar: zio/aws/sagemaker/model/CreateEndpointConfigRequest.scala <==
package zio.aws.sagemaker.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.sagemaker.model.primitives.{KmsKeyId, EndpointConfigName}
import scala.jdk.CollectionConverters._
final case class CreateEndpointConfigRequest(
    endpointConfigName: EndpointConfigName,
    productionVariants: Iterable[zio.aws.sagemaker.model.ProductionVariant],
    dataCaptureConfig: Optional[zio.aws.sagemaker.model.DataCaptureConfig] =
      Optional.Absent,
    tags: Optional[Iterable[zio.aws.sagemaker.model.Tag]] = Optional.Absent,
    kmsKeyId: Optional[KmsKeyId] = Optional.Absent,
    asyncInferenceConfig: Optional[
      zio.aws.sagemaker.model.AsyncInferenceConfig
    ] = Optional.Absent,
    explainerConfig: Optional[zio.aws.sagemaker.model.ExplainerConfig] =
      Optional.Absent,
    shadowProductionVariants: Optional[
      Iterable[zio.aws.sagemaker.model.ProductionVariant]
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.CreateEndpointConfigRequest = {
    import CreateEndpointConfigRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.CreateEndpointConfigRequest
      .builder()
      .endpointConfigName(
        EndpointConfigName.unwrap(endpointConfigName): java.lang.String
      )
      .productionVariants(productionVariants.map { item =>
        item.buildAwsValue()
      }.asJavaCollection)
      .optionallyWith(dataCaptureConfig.map(value => value.buildAwsValue()))(
        _.dataCaptureConfig
      )
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .optionallyWith(
        kmsKeyId.map(value => KmsKeyId.unwrap(value): java.lang.String)
      )(_.kmsKeyId)
      .optionallyWith(asyncInferenceConfig.map(value => value.buildAwsValue()))(
        _.asyncInferenceConfig
      )
      .optionallyWith(explainerConfig.map(value => value.buildAwsValue()))(
        _.explainerConfig
      )
      .optionallyWith(
        shadowProductionVariants.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.shadowProductionVariants)
      .build()
  }
  def asReadOnly: zio.aws.sagemaker.model.CreateEndpointConfigRequest.ReadOnly =
    zio.aws.sagemaker.model.CreateEndpointConfigRequest.wrap(buildAwsValue())
}
object CreateEndpointConfigRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.CreateEndpointConfigRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.CreateEndpointConfigRequest =
      zio.aws.sagemaker.model.CreateEndpointConfigRequest(
        endpointConfigName,
        productionVariants.map { item =>
          item.asEditable
        },
        dataCaptureConfig.map(value => value.asEditable),
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        kmsKeyId.map(value => value),
        asyncInferenceConfig.map(value => value.asEditable),
        explainerConfig.map(value => value.asEditable),
        shadowProductionVariants.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def endpointConfigName: EndpointConfigName
    def productionVariants
        : List[zio.aws.sagemaker.model.ProductionVariant.ReadOnly]
    def dataCaptureConfig
        : Optional[zio.aws.sagemaker.model.DataCaptureConfig.ReadOnly]
    def tags: Optional[List[zio.aws.sagemaker.model.Tag.ReadOnly]]
    def kmsKeyId: Optional[KmsKeyId]
    def asyncInferenceConfig
        : Optional[zio.aws.sagemaker.model.AsyncInferenceConfig.ReadOnly]
    def explainerConfig
        : Optional[zio.aws.sagemaker.model.ExplainerConfig.ReadOnly]
    def shadowProductionVariants
        : Optional[List[zio.aws.sagemaker.model.ProductionVariant.ReadOnly]]
    def getEndpointConfigName: ZIO[Any, Nothing, EndpointConfigName] =
      ZIO.succeed(endpointConfigName)
    def getProductionVariants: ZIO[Any, Nothing, List[
      zio.aws.sagemaker.model.ProductionVariant.ReadOnly
    ]] = ZIO.succeed(productionVariants)
    def getDataCaptureConfig: ZIO[
      Any,
      AwsError,
      zio.aws.sagemaker.model.DataCaptureConfig.ReadOnly
    ] = AwsError.unwrapOptionField("dataCaptureConfig", dataCaptureConfig)
    def getTags
        : ZIO[Any, AwsError, List[zio.aws.sagemaker.model.Tag.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
    def getKmsKeyId: ZIO[Any, AwsError, KmsKeyId] =
      AwsError.unwrapOptionField("kmsKeyId", kmsKeyId)
    def getAsyncInferenceConfig: ZIO[
      Any,
      AwsError,
      zio.aws.sagemaker.model.AsyncInferenceConfig.ReadOnly
    ] = AwsError.unwrapOptionField("asyncInferenceConfig", asyncInferenceConfig)
    def getExplainerConfig
        : ZIO[Any, AwsError, zio.aws.sagemaker.model.ExplainerConfig.ReadOnly] =
      AwsError.unwrapOptionField("explainerConfig", explainerConfig)
    def getShadowProductionVariants: ZIO[Any, AwsError, List[
      zio.aws.sagemaker.model.ProductionVariant.ReadOnly
    ]] = AwsError.unwrapOptionField(
      "shadowProductionVariants",
      shadowProductionVariants
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.CreateEndpointConfigRequest
  ) extends zio.aws.sagemaker.model.CreateEndpointConfigRequest.ReadOnly {
    override val endpointConfigName: EndpointConfigName =
      zio.aws.sagemaker.model.primitives
        .EndpointConfigName(impl.endpointConfigName())
    override val productionVariants
        : List[zio.aws.sagemaker.model.ProductionVariant.ReadOnly] = impl
      .productionVariants()
      .asScala
      .map { item =>
        zio.aws.sagemaker.model.ProductionVariant.wrap(item)
      }
      .toList
    override val dataCaptureConfig
        : Optional[zio.aws.sagemaker.model.DataCaptureConfig.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.dataCaptureConfig())
        .map(value => zio.aws.sagemaker.model.DataCaptureConfig.wrap(value))
    override val tags: Optional[List[zio.aws.sagemaker.model.Tag.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.tags())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.sagemaker.model.Tag.wrap(item)
          }.toList
        )
    override val kmsKeyId: Optional[KmsKeyId] = zio.aws.core.internal
      .optionalFromNullable(impl.kmsKeyId())
      .map(value => zio.aws.sagemaker.model.primitives.KmsKeyId(value))
    override val asyncInferenceConfig
        : Optional[zio.aws.sagemaker.model.AsyncInferenceConfig.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.asyncInferenceConfig())
        .map(value => zio.aws.sagemaker.model.AsyncInferenceConfig.wrap(value))
    override val explainerConfig
        : Optional[zio.aws.sagemaker.model.ExplainerConfig.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.explainerConfig())
        .map(value => zio.aws.sagemaker.model.ExplainerConfig.wrap(value))
    override val shadowProductionVariants
        : Optional[List[zio.aws.sagemaker.model.ProductionVariant.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.shadowProductionVariants())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.sagemaker.model.ProductionVariant.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.CreateEndpointConfigRequest
  ): zio.aws.sagemaker.model.CreateEndpointConfigRequest.ReadOnly = new Wrapper(
    impl
  )
}
